courses.ActiveActivities (Current activities) — amici1

# `courses.ActiveActivities` (Current activities)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.DateField: start_date>`

- `<lino.core.fields.TimeField: start_time>`

- `<django.db.models.fields.DateField: end_date>`

- `<lino.core.fields.TimeField: end_time>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<lino.core.choicelists.ChoiceListField: every_unit>`

- `<django.db.models.fields.IntegerField: every>`

- `<django.db.models.fields.CharField: positions>`

- `<django.db.models.fields.BooleanField: monday>`

- `<django.db.models.fields.BooleanField: tuesday>`

- `<django.db.models.fields.BooleanField: wednesday>`

- `<django.db.models.fields.BooleanField: thursday>`

- `<django.db.models.fields.BooleanField: friday>`

- `<django.db.models.fields.BooleanField: saturday>`

- `<django.db.models.fields.BooleanField: sunday>`

- `<django.db.models.fields.PositiveIntegerField: max_events>`

- `<django.db.models.fields.related.ForeignKey: room>`

- `<django.db.models.fields.DateField: max_date>`

- `<django.db.models.fields.related.ForeignKey: line>`

- `<django.db.models.fields.related.ForeignKey: teacher>`

- `<django.db.models.fields.related.ForeignKey: slot>`

- `<lino.utils.mldbc.fields.BabelTextField: description>`

- `<django.db.models.fields.TextField: remark>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<django.db.models.fields.PositiveIntegerField: max_places>`

- `<django.db.models.fields.CharField: name>`

- `<django.db.models.fields.DateField: enrolments_until>`

Detail fields

- `<Panel general in lino_xl.lib.courses.desktop.CourseDetail on lino_xl.lib.courses.desktop.Activities>`

- `<Panel cal_tab in lino_xl.lib.courses.desktop.CourseDetail on lino_xl.lib.courses.desktop.Activities>`

- `<Panel enrolments in lino_xl.lib.courses.desktop.CourseDetail on lino_xl.lib.courses.desktop.Activities>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Activity.

- Create (submit_insert) : Create the record and open a detail window on it

- ⚇ (duplicate) : Duplicate the selected row.

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Presence sheet (print_presence_sheet) : Print using a hard-coded template and without cache.

- Presence sheet (HTML) (print_presence_sheet_html) : Print using a hard-coded template and without cache.

- Today (show_today) : Show all calendar events of the same day.

- Update Events (do_update_events) : Create or update the automatic calendar entries controlled by this generator.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- Update presences (update_all_guests) : Update the presence lists of all calendar events generated by this.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

Filter parameters

- `<django.db.models.fields.related.ForeignKey: line>`

- `<django.db.models.fields.related.ForeignKey: topic>`

- `<django.db.models.fields.related.ForeignKey: teacher>`

- `<lino.core.choicelists.ChoiceListField: show_exposed>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<lino.core.choicelists.ChoiceListField: can_enroll>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: room>`

## Filter parameters